@@ -1,8 +1,14 @@
 #nocov start
 .onLoad <- function(...) {
   register_s3_method("tidyr", "unnest", "bench_mark")
+  register_s3_method("dplyr", "filter", "bench_mark")
+  register_s3_method("dplyr", "group_by", "bench_mark")
   register_s3_method("ggplot2", "autoplot", "bench_mark")
 
+  register_s3_method("pillar", "pillar_shaft", "bench_expr")
+  register_s3_method("pillar", "type_sum", "bench_expr")
+  register_s3_method("ggplot2", "scale_type", "bench_expr")
+
   register_s3_method("pillar", "pillar_shaft", "bench_time")
   register_s3_method("pillar", "type_sum", "bench_time")
   register_s3_method("ggplot2", "scale_type", "bench_time")
